#
# spec file for package open-vmdk
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           open-vmdk
Version:        0.3.10
Release:        1.1
Summary:        Tools to create OVA files from raw disk images
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/vmware/open-vmdk
Source0:        https://github.com/vmware/open-vmdk/archive/refs/tags/v%{version}.tar.gz
Patch0:         shebang.patch
BuildRequires:  zlib-devel
Requires:       coreutils
Requires:       grep
Requires:       python3-PyYAML
Requires:       python3-lxml
Requires:       sed
Requires:       tar
Requires:       util-linux

%description
Tools to create OVA files from raw disk images. This includes 'vmdk-convert'
to create VMDKs from raw disk images, and 'ova-compose' to create OVA files
that can be imported by VMware vSphere or Fusion and Workstation.

%prep

%setup -q
%autopatch -p1

%build
%make_build

%install
install -d %{buildroot}%{_sysconfdir}
%make_install
install templates/*.ovf %{buildroot}%{_datadir}/%{name}

%files

%dir %{_datadir}/%{name}
%{_datadir}/%{name}
%{_bindir}/*
%config %{_sysconfdir}/*

%changelog
* Fri Feb 14 2025 Dirk Müller <dmueller@suse.com>
- update to 0.3.10:
  * mkova.sh: bail if vmdk-convert is not in PATH
  * fix `abspath()` in `OVFFile`
  * bump spec version to 0.3.10-0
  * ova-compose: add option to set tar format (default: `gnu`)
- update to 0.3.9:
  * add disk_id/file_id options for disk images
  * ova-compose: support sha1 checksum type
  * ova-compose: fix slowness of hashsum generation
  * ova-compose: add raw_image option for disks
- update to 0.3.8:
  * add spec file
  * add 'None' to name spaces
  * fix password setting in properties (was always false)
  * add support for multiple product sections
  * add 'units' option for disk images
- update to 0.3.7:
  * Honor compiler/linker flags from the environment
  * add NVME and USB3 controllers
  * set default checksum type to sha256
* Tue Nov 21 2023 andreas.stieger@gmx.de
- Update to version 0.3.6.0:
  * -add a test for the manifest file
  * add option to support sha256 checksum type
  * add github workflow for pytest
  * add basic tests with pytest
  * do not fail if 'transports' or 'categories' are missing
  * Update README.md for categories and extra_configs
  * don't fail if no network is configured
  * add 'no_default_configs' option to 'system'
  * add categories, fixes issue #35
  * add extra_configs
  * Add doc for OVF properties to README.md
  * fix for split failure when there is more than one equals sign in 'param'
  * fix error when product section doesn't exist
  * Add OVF template for hardware version 21
  * Fix typo, from PR #29
  * fix vmdisk ids
  * add OVF properties
* Thu Nov 16 2023 Guilherme Moro <gmoro@suse.com>
- Patch: shebang.patch fix bash/sh shebang issue
* Fri Aug 25 2023 gmoro@suse.com
- Update to version 0.3.1.0:
  * create $(DESTDIR)/etc/ if it does not exist
  * document `configuration` in the README.
  * add OVF configurations
  * Update README.md
  * add -m/--manifest option to create manifest with OVF
  * support empty disks
  * typo
  * Document ova-compose, declare mkova.sh legacy
  * up level titles
* Tue May  9 2023 Klaus Kämpf <kkaempf@suse.com>
- install /etc/open-vmdk.conf
* Fri May  5 2023 Klaus Kämpf <kkaempf@suse.com>
- Initial version 0.2.0+git20230503.777215f
